@@ -11,18 +11,75 @@ use File::HomeDir ();
 use Params::Util  qw{ _STRING _ARRAY };
 use YAML::Tiny    ();
 
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 
+my %defaults = (
+	# Number of modules to display when searching for documentation
+	pod_maxlist               => 200,
+	pod_minlist               => 2,
 
+	# startup mode, if no files given on the command line this can be
+	#   new        - a new empty buffer
+	#   nothing    - nothing to open
+	#   last       - the files that were open last time
+	main_startup              => 'new',
+
+	# Look and feel preferences
+	main_statusbar            => 1,
+	main_output               => 0,
+	main_rightbar             => 1,
+	editor_linenumbers        => 0,
+	editor_eol                => 0,
+	editor_indentationguides  => 0,
+	editor_calltips           => 1,
+	editor_autoindent         => 'deep',
+	editor_whitespaces        => 0,
+	editor_methods            => 'alphabetical',
+	editor_codefolding        => 0,
+
+	# Indentation settings
+	editor_auto_indentation_style => 0,
+	editor_use_tabs               => 1,
+	editor_tabwidth               => 8,
+	editor_indentwidth            => 4,
+
+	# When running a script from the application some of the files might have not been saved yet.
+	# There are several option what to do before running the script
+	# none - don's save anything
+	# same - save the file in the current buffer
+	# all_files - all the files (but not buffers that have no filenames)
+	# all_buffers - all the buffers even if they don't have a name yet
+	run_save                  => 'same',
+
+	# Search and replace recent values
+	search_terms              => [],
+	replace_terms             => [],
+
+	# Various things that should probably be in the database
+	bookmarks                 => {},
+	projects                  => {},
+	current_project           => '',
+
+	# By default we have an empty plugins configuration
+	plugins                   => {},
+
+	# By default, use background threads unless profiling
+	use_worker_threads        => 1,
+
+	# By default, don't enable experimental features
+	experimental              => 0,
+);
 
 
 
 #####################################################################
 # Class-Level Functionality
 
-my $DEFAULT_DIR = File::Spec->catfile(
-	($ENV{PADRE_HOME} ? $ENV{PADRE_HOME} : File::HomeDir->my_data),
-	'.padre'
+my $DEFAULT_DIR = File::Spec->catfile( (
+	$ENV{PADRE_HOME}
+		? $ENV{PADRE_HOME}
+		: File::HomeDir->my_data
+	), '.padre',
 );
 
 sub default_dir {
@@ -31,7 +88,6 @@ sub default_dir {
 		mkdir $dir or
 		die "Cannot create config dir '$dir' $!";
 	}
-
 	return $dir;
 }
 
@@ -62,23 +118,22 @@ sub default_plugin_dir {
 		die "Cannot create plugins dir '$plugins_full_path' $!";
 	}
 
-	# copy the My Plugin if necessary
+	# Copy the My Plugin if necessary
 	my $file = File::Spec->catfile( $plugins_full_path, 'My.pm' );
-	if (not -e $file) {
+	unless ( -e $file ) {
 		Padre::Config->copy_original_My_plugin( $file );
 	}
 	return $pluginsdir;
 }
 
-
 sub copy_original_My_plugin {
 	my $class = shift;
 	my $target = shift;
 	my $src = File::Spec->catfile( File::Basename::dirname($INC{'Padre/Config.pm'}), 'Plugin', 'My.pm' );
-	if (not $src) {
+	unless ( $src ) {
 		die "Could not find the original My plugin";
 	}
-	if (not File::Copy::copy($src, $target) ) {
+	unless ( File::Copy::copy($src, $target) ) {
 		return die "Could not copy the My plugin ($src) to $target: $!";
 	}
 	chmod 0644, $target;
@@ -87,6 +142,9 @@ sub copy_original_My_plugin {
 }
 
 
+
+
+
 #####################################################################
 # Constructor and Serialization
 
@@ -99,10 +157,6 @@ sub new {
 	$self->{host}->{main_width}     ||= 600;
 	$self->{host}->{main_left}      ||= 40;
 	$self->{host}->{main_top}       ||= 20;
-#	$self->{host}->{main_height}    ||= Wx::wxDefaultSize()->height;
-#	$self->{host}->{main_width}     ||= Wx::wxDefaultSize()->width;
-#	$self->{host}->{main_left}      ||= Wx::wxDefaultPosition()->x;
-#	$self->{host}->{main_top}       ||= Wx::wxDefaultPosition()->y;
 	$self->{host}->{main_maximized} ||= 0;
 
 	# Files that were previously open (and can be still)
@@ -120,64 +174,7 @@ sub new {
 	# When they want to run an arbitrary command
 	$self->{host}->{run_command}    ||= '';
 
-	my %defaults = (
 
-		# Number of modules to display when searching for documentation
-		pod_maxlist               => 200,
-		pod_minlist               => 2,
-
-		# startup mode, if no files given on the command line this can be
-		#   new        - a new empty buffer
-		#   nothing    - nothing to open
-		#   last       - the files that were open last time
-		main_startup              => 'new',
-	
-		# Look and feel preferences
-		main_statusbar            => 1,
-		main_output               => 0,
-		main_rightbar             => 1,
-		editor_linenumbers        => 0,
-		editor_eol                => 0,
-		editor_indentationguides  => 0,
-		editor_calltips           => 1,
-		editor_autoindent         => 'deep',
-		editor_whitespaces        => 0,
-		editor_methods            => 'alphabetical',
-		
-		# Indentation settings
-		editor_auto_indentation_style => 0,
-		editor_use_tabs               => 1,
-		editor_tabwidth               => 8,
-		editor_indentwidth            => 4,
-
-		# When running a script from the application some of the files might have not been saved yet.
-		# There are several option what to do before running the script
-		# none - don's save anything
-		# same - save the file in the current buffer
-		# all_files - all the files (but not buffers that have no filenames)
-		# all_buffers - all the buffers even if they don't have a name yet
-		run_save                  => 'same',
-
-		# Search and replace recent values
-		search_terms              => [],
-		replace_terms             => [],
-        ack_terms                 => [],
-        ack_dirs                  => [],
-
-		# Various things that should probably be in the database
-		bookmarks                 => {},
-		projects                  => {},
-		current_project           => '',
-
-		# By default we have an empty plugins configuration
-		plugins                   => {},
-
-		# By default, use background threads unless profiling
-		use_worker_threads        => 1,
-
-		# By default, don't enable experimental features
-		experimental              => 0,
-	);
 	%$self = (%defaults, %$self);
 
 	return $self;
@@ -243,12 +240,10 @@ sub write {
 	# Serialize some values
 	$copy->{host}->{main_files} = join( "\n", grep { defined } @{$copy->{host}->{main_files}} );
 	$copy->{host}->{main_files_pos} = join( "\n", grep { defined } @{$copy->{host}->{main_files_pos}} );
-	
+
 	# Limit the search_terms/replace_terms
 	@{$copy->{search_terms}}  = splice(@{$copy->{search_terms}},  0, 20);
 	@{$copy->{replace_terms}} = splice(@{$copy->{replace_terms}}, 0, 20);
-	@{$copy->{ack_terms}}     = splice(@{$copy->{ack_terms}},  0, 20);
-	@{$copy->{ack_dirs}}      = splice(@{$copy->{ack_dirs}}, 0, 20);
 
 	# Save the host configuration
 	Padre::DB->hostconf_write( delete $copy->{host} );
