@@ -30,7 +30,7 @@ use FindBin      ();
 use File::Spec   ();
 use List::Util   qw(first);
 
-our $VERSION   = '0.21';
+our $VERSION   = '0.22';
 our @ISA       = 'Exporter';
 our @EXPORT_OK = qw(newline_type get_matches);
 
@@ -121,9 +121,9 @@ sub get_matches {
 			$pair = $matches[-1];
 		}
 	} else {
-		$pair = first {$from < $_->[0]}         @matches;
+		$pair = first {$from < $_->[0]} @matches;
 		if (not $pair and @matches) {
-		    $pair = $matches[0];
+			$pair = $matches[0];
 		}
 	}
 
@@ -151,18 +151,21 @@ sub sharefile {
 	File::Spec->catfile( share(), @_ );
 }
 
-
 package Px;
 
 use constant {
-	PASM_KEYWORD  => 1,
-	PASM_REGISTER => 2,
-	PASM_LABEL    => 3,
-	PASM_STRING   => 4,
-	PASM_COMMENT  => 5,
-	PASM_POD      => 6,
+	PADRE_BLACK         => 0,
+	PADRE_BLUE          => 1,
+	PADRE_RED           => 2,
+	PADRE_GREEN         => 3,
+	PADRE_MAGENTA       => 4,
+	PADRE_ORANGE        => 5,
+	PADRE_DIM_GRAY      => 6,
+	PADRE_CRIMSON       => 7,
+	PADRE_BROWN         => 8,
 };
 
+
 1;
 
 =head1 SUPPORT
